package org.example.domain

import org.example.data.FavouriteRepository
import org.example.data.ShoesRepository
import org.example.data.UserRepository
import org.example.domain.request.AuthorizeRequest
import org.example.domain.request.ChangePasswordRequest
import org.example.domain.request.RegistrationRequest
import org.example.domain.response.UserResponse

class UserUseCaseImpl(
    private val userRepository: UserRepository,
    private val  favouriteRepository: FavouriteRepository,
    private val shoesRepository: ShoesRepository
    ): UserUseCase {
    override fun authorize(authorizeRequest: AuthorizeRequest): UserResponse {
        val findUser = userRepository.getAllUsers()
            .firstOrNull {
                it.email == authorizeRequest.email
            }
        checkNotNull(findUser){
            "Пользователь с такой почтой не найден"
        }
        require(findUser.password == authorizeRequest.password){
            "Пароли не совпадают"
        }
        val favourite = favouriteRepository.getFavouritesByUserId(userID = findUser.userId)
        val shoesFavourite = shoesRepository.getAllShoes().filter { it.shoesId in favourite}
        return userDtoToUserResponse(findUser, shoesFavourite)
    }

    override fun registration(registrationRequest: RegistrationRequest): UserResponse {
        //уникальность почты
        val isUnique = userRepository.getAllUsers().firstOrNull{
            it.email == registrationRequest.email
        } == null
        require(isUnique){
            "Такая почта уже существует"
        }
        val newUser = userRepository.addUser(registrationRequest)
        return userDtoToUserResponse(newUser)
    }

    override fun changePassword(changePasswordRequest: ChangePasswordRequest) {
        val updatedUser = userRepository.findUserById(changePasswordRequest.userId)
        updatedUser.password = changePasswordRequest.newPassword
        userRepository.updateUserById(changePasswordRequest.userId, updatedUser)
    }




    override fun changeProfile() {
        TODO("Not yet implemented")
    }
}